/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#include "include/gnotifylib.h"

int gnotify_init(char *host)
{
	int sockfd;
	int connection;
	struct sockaddr_in servaddr;
	struct hostent *host_info;
	unsigned long addr;
	
	sockfd = socket(AF_INET, SOCK_STREAM, 0);
	if(sockfd < 0)
		return(sockfd);
  memset(&servaddr,0,sizeof(servaddr));
  if((addr=inet_addr(host))!=INADDR_NONE)
	{
    memcpy((char*)&servaddr.sin_addr,&addr,sizeof(addr));
  }
  else
	{
    host_info = gethostbyname(host);
    if(NULL==host_info)
      return(-1);
    memcpy((char*)&servaddr.sin_addr,host_info->h_addr,host_info->h_length);
  }
	servaddr.sin_family=AF_INET;
	servaddr.sin_port=htons(7206);
  if((connection=connect(sockfd,(struct sockaddr*)&servaddr,sizeof(servaddr)))<0)
	{
		close(sockfd);
		return(connection);
	}
	return(sockfd);
}

void gnotify_quit(int sockhdl)
{
	gnotify_send_raw_string(sockhdl,"QUIT");
	close(sockhdl);
	return;
}

int gnotify_send_raw_string(int sockhdl, char *string, ...)
{
  va_list ap;
  char output[1022];
  va_start(ap, string);
  vsprintf(output, string, ap);
  va_end(ap);
  return(send(sockhdl,output,1+strlen(output),0));
}

int gnotify_get_return(int sockhdl)
{
  char buff[128];
	char value[4];
  
  recv(sockhdl,buff,sizeof(buff),0);
  strncpy(value,buff,3);
  return(atoi(value));
}

int gnotify_set_title(int sockhdl, char *string)
{
	return(gnotify_send_raw_string(sockhdl,"APP:%s",string));
}

int gnotify_set_icon(int sockhdl, char *string)
{
	return(gnotify_send_raw_string(sockhdl,"ICON:%s",string));
}

int gnotify_set_button(int sockhdl, char *string)
{
	return(gnotify_send_raw_string(sockhdl,"BTN:%s",string));
}

int gnotify_set_snd(int sockhdl, char *string)
{
	return(gnotify_send_raw_string(sockhdl,"SND:%s",string));
}

int gnotify_set_x_position(int sockhdl, char *string)
{
	return(gnotify_send_raw_string(sockhdl,"MVX:%s",string));
}

int gnotify_set_y_position(int sockhdl, char *string)
{
	return(gnotify_send_raw_string(sockhdl,"MVY:%s",string));
}

int gnotify_set_checkbox(int sockhdl, char *string)
{
	return(gnotify_send_raw_string(sockhdl,"CKB:%s",string));
}

int gnotify_notify(int sockhdl, char *string)
{
	return(gnotify_send_raw_string(sockhdl,"MSG:%s",string));
}


/* --- special functions --- */

int gnotify_reload(int sockhdl)
{
	return(gnotify_send_raw_string(sockhdl,"RELOAD"));
}

int gnotify_save_configuration(int sockhdl)
{
	return(gnotify_send_raw_string(sockhdl,"SAVECONFIG"));
}

int gnotify_set_configuration(int sockhdl, char *string, char *value)
{
	return(gnotify_send_raw_string(sockhdl,"SETCFG:%s:%s",string,value));
}

char *gnotify_get_configuration(int sockhdl, char *string)
{
  char buff[128];
	static char value[64];
  
	if(gnotify_send_raw_string(sockhdl,"GETCFG:%s",string)!=0)
		return(NULL);
  recv(sockhdl,buff,sizeof(buff),0);
	if(strncmp(buff,"214",3)==0)
	{
	  strcpy(value,&buff[strlen(buff)-strlen(string)-5]);
		return(value);
	}
	else
	{
		return(NULL);
	}
	return(NULL);
}
